# OptiSwap

We provide a reference implementation of the OptiSwap protocol submitted to the Financial Cryptography and Data Security conference 2020.

The contracts within this repository are used as a proof of concept for a file sale application.
We stress that they are not audited for implementation bugs.
Therefore, they should be used with caution.
